@@ -1,7 +1,9 @@
+class NoFileStorageException(Exception):
+    pass
+
 class BaseStorage(object):
-    def __init__(self, prefix, *args, **kwargs):
+    def __init__(self, prefix):
         self.prefix = 'formwizard_%s' % prefix
-        super(BaseStorage, self).__init__(*args, **kwargs)
 
     def get_current_step(self):
         raise NotImplementedError()
@@ -12,9 +14,18 @@ class BaseStorage(object):
     def get_step_data(self, step):
         raise NotImplementedError()
 
+    def get_current_step_data(self):
+        raise NotImplementedError()
+
     def set_step_data(self, step, cleaned_data):
         raise NotImplementedError()
 
+    def get_step_files(self, step):
+        raise NotImplementedError()
+
+    def set_step_files(self, step, files):
+        raise NotImplementedError()
+
     def get_extra_context_data(self):
         raise NotImplementedError()
 
