@@ -1,5 +1,5 @@
 from django import forms
-from formwizard.contrib.forms import NamedUrlSessionFormWizard
+from formwizard.forms import NamedUrlFormWizard
 from django.http import HttpResponse
 from django.template import Template, Context
 from django.contrib.auth.models import User
@@ -19,11 +19,11 @@ class Page3(forms.Form):
 
 Page4 = formset_factory(Page3, extra=2)
 
-class ContactWizard(NamedUrlSessionFormWizard):
-    def done(self, request, form_list):
-        c = Context({'form_list': [x.cleaned_data for x in form_list], 'all_cleaned_data': self.get_all_cleaned_data()})
+class ContactWizard(NamedUrlFormWizard):
+    def done(self, request, storage, form_list, **kwargs):
+        c = Context({'form_list': [x.cleaned_data for x in form_list], 'all_cleaned_data': self.get_all_cleaned_data(request, storage)})
         for form in self.form_list.keys():
-            c[form] = self.get_cleaned_data_for_step(form)
+            c[form] = self.get_cleaned_data_for_step(request, storage, form)
 
-        c['this_will_fail'] = self.get_cleaned_data_for_step('this_will_fail')
+        c['this_will_fail'] = self.get_cleaned_data_for_step(request, storage, 'this_will_fail')
         return HttpResponse(Template('').render(c))
\ No newline at end of file
